Module prime

Module prime 

Functions

find_next_prime
Finds the lowest prime number which is greater than the provided number n.
find_next_prime_with_load_factor
is_prime
Checks whether the provided number n is a prime number.